#!/usr/bin/env python3
# -*- coding: utf-8 -*-
import xlrd
class ReadExcel():
    def __init__(self,f_xp):
        self.table_config= xlrd.open_workbook(f_xp).sheet_by_name('config')
        self.base_url=[]
        for k in range(1,self.table_config.ncols):
            self.base_url.append(self.table_config.cell_value(1,k))
        self.table_cases=xlrd.open_workbook(f_xp).sheet_by_name('case')
        self.nrows=self.table_cases.nrows
        self.ncols=self.table_config.ncols

    def read_case(self):
        case_data=[]
        try:
            for i in range(1,self.nrows):
                case = {}
                case['case_name']=self.table_cases.cell_value(i,0)
                case['method']=self.table_cases.cell_value(i,1)
                if 'BU_' in self.table_cases.cell_value(i,2):
                    rep=self.table_cases.cell_value(i,2)[0:4]
                    case['url']=self.table_cases.cell_value(i,2).replace(rep,self.base_url[int(rep[3:4])-1])
                else:
                    case['url'] = self.table_cases.cell_value(i, 2)
                case['params']=self.table_cases.cell_value(i,3)
                case['data']=self.table_cases.cell_value(i,4)
                case['expectation']=self.table_cases.cell_value(i,5)
                case['Preconditions']=self.table_cases.cell_value(i,6)
                case['get_params']=self.table_cases.cell_value(i,7)
                case_data.append(case)
            return case_data

        except:
            print('测试用例异常')

    def read_db_config(self):
        db_config = {'host': '', 'user': '', 'passwd': '', 'port': '', 'db': ''}
        try:
            db_config['host'] = self.table_config.cell_value(7, 1)
            db_config['user'] = self.table_config.cell_value(8, 1)
            db_config['passwd'] = self.table_config.cell_value(9, 1)
            db_config['port'] = int(self.table_config.cell_value(10, 1))
            db_config['db'] = self.table_config.cell_value(11, 1)
            return db_config

        except:
            print('配置数据异常1')

    def read_user_config(self):
        user_config = {'login_url': '', 'loginBy': '', 'password': ''}
        try:
            user_config['login_url'] =self.table_config.cell_value(3, 1)
            user_config['loginBy'] = self.table_config.cell_value(4, 1)
            user_config['password'] = self.table_config.cell_value(5, 1)
            return user_config

        except:
            print('配置数据异常2')

    def read_shh_config(self):
        ssh_config = {'ssh_host': '', 'ssh_port': '', 'keyfile': '', 'ssh_user': ''}
        try:
            ssh_config['ssh_host'] = self.table_config.cell_value(13, 1)
            ssh_config['ssh_port'] = int(self.table_config.cell_value(14, 1))
            ssh_config['keyfile'] = self.table_config.cell_value(15, 1)
            ssh_config['ssh_user'] = self.table_config.cell_value(16, 1)

            return ssh_config

        except:
            print('配置数据异常3')




#!/usr/bin/env python3
# -*- coding: utf-8 -*-
import os,time,unittest,sys
pathname = os.getcwd()
sys.path.append(pathname)
from mmdminterface import HTMLTestRunner
def Html_Runner(test_cases):
    suite = unittest.TestSuite()
    suite.addTests(unittest.TestLoader().loadTestsFromTestCase(test_cases))
    now = time.strftime('%Y-%m-%d %I_%M_%S_%p')
    basedir = os.path.abspath(os.path.dirname(__file__))
    file_dir = os.path.join(basedir, 'report/history_report')
    file = os.path.join(file_dir, (now + '.html'))
    re_open = open(file, 'wb')
    runner = HTMLTestRunner.HTMLTestRunner(stream=re_open, title='接口测试报告', description='测试结果')
    runner.run(suite)
    last_report = os.path.join(os.path.join(basedir, 'report/last_report'),'last_report.html')
    with open(last_report, "wb") as nf, open(file, "rb") as of:
        nf.write(of.read())


#!/usr/bin/env python3
# -*- coding: utf-8 -*-
import re
from requests import Request,Session
import unittest
from mmdminterface import read_test_data,ddt
global case_date
case_date=[]

@ddt.ddt
class Interface(unittest.TestCase):

    def __init__(self,f_xP, methodName='runTest'):
        """Create an instance of the class that will use the named test
           method when executed. Raises a ValueError if the instance does
           not have a method with the specified name.
        """'/Users/mckay/JMeter/minterface/examples/demo2/test_data/test_case_data.xls'
        self._testMethodName = methodName
        self._outcome = None
        self._testMethodDoc = 'No test'
        try:
            testMethod = getattr(self, methodName)
        except AttributeError:
            if methodName != 'runTest':
                # we allow instantiation with no explicit method name
                # but not an *incorrect* or missing method name
                raise ValueError("no such test method in %s: %s" %
                      (self.__class__, methodName))
        else:
            self._testMethodDoc = testMethod.__doc__
        self._cleanups = []
        self._subtest = None

        # Map types to custom assertEqual functions that will compare
        # instances of said type in more detail to generate a more useful
        # error message.
        self._type_equality_funcs = {}
        self.addTypeEqualityFunc(dict, 'assertDictEqual')
        self.addTypeEqualityFunc(list, 'assertListEqual')
        self.addTypeEqualityFunc(tuple, 'assertTupleEqual')
        self.addTypeEqualityFunc(set, 'assertSetEqual')
        self.addTypeEqualityFunc(frozenset, 'assertSetEqual')
        self.addTypeEqualityFunc(str, 'assertMultiLineEqual')
        self.case_date = read_test_data.ReadExcel(f_xP).read_case()


    def setUp(self):
        self.new_case_date =self.case_date
        self.reponses={}

    def rep_params(self, case_date):
        reps=re.compile('(\$\{.*\})')
        keys=reps.findall(case_date)
        for key in keys:
            case_date=case_date.replace(key,self.reponses[key])
        return case_date

    def get_params(self,text,rule):
        rep = re.compile(rule)
        return rep.findall(text)[0]

    def get_req(self,case_date):
        if '$' in case_date['url']:
            case_date['url']=self.rep_params(case_date['url'])
        if case_date['params']!='':
            return Request(case_date['method'], case_date['url'], params=eval(case_date['params']))
        elif case_date['data']!='':
            if '$' in case_date['data']:
                case_date['data'] = self.rep_params(case_date['data'])
            return Request(case_date['method'], case_date['url'], json=eval(case_date['data']))
        else:
            return Request(case_date['method'], case_date['url'])

    @ddt.data(*case_date)
    def test(self, case_date):
        case = [int(x) for x in case_date['Preconditions'].split(',')]
        session=Session()
        for i in case:
            req =self.get_req(self.new_case_date[i-1])
            prepped = session.prepare_request(req)
            sent = session.send(prepped)
            self.assertEqual(sent.status_code,200)
            self.assertTrue(self.new_case_date[i - 1]['expectation'] in str(sent.text))
            if self.new_case_date[i-1]['get_params']!='':
                print(self.new_case_date[i-1]['get_params'])
                dict_case_date=eval(self.new_case_date[i - 1]['get_params'])
                for key in dict_case_date.keys():
                    self.reponses[key]=self.get_params(sent.text,dict_case_date[key])


    def tearDown(self):
        pass

if __name__=='__main__':

    cc=Interface('/Users/mckay/JMeter/minterface/examples/demo2/test_data/test_case_data.xls')





#!/usr/bin/env python3
# -*- coding: utf-8 -*-
import re,yaml,random
import unittest
from requests import Request,Session
reponses={}
class interface(unittest.TestCase):

	#create china world
	def create_Unicode(self,num=None):
		if num!=None:
			return ''.join(chr(random.randint(0x4e00, 0x9fbf)) for _ in range(3))
		else:
			return ''.join(chr(random.randint(0x4e00, 0x9fbf)) for _ in range(int(num)))

	# create user_name
	def create_user_name(self):
		return ''.join(chr(random.choice(range(97, 122))) for _ in range(8))

	#create email
	def create_email(self):
		maillist = ["@qq.mmdminterface", "@gmail.mmdminterface", "@sina.mmdminterface"]
		return ''.join( chr(random.choice(range(97,122))) for _ in range(8))+random.choice(maillist)

	#create phone number
	def create_pn(self):
		pholist = ["130", "131", "132", "133", "134", "135", "136", "137", "138", "139", "147", "150", "151", "152",
				   "153", "155", "156", "157", "158", "159", "186", "187", "188"]
		return random.choice(pholist) +''.join( str(random.choice(range(10))) for _ in range(8))

	def save_params(self, text, rule):

		for i in rule.keys():
			rep = re.compile(rule[i])
			reponses[i] = rep.findall(text)[0]
		return reponses

	def read_yaml(self,file):
		f = open(file, 'r', encoding='utf-8')
		cont = f.read()
		self.urls = yaml.load(cont)['url']
		return yaml.load(cont)['users']



	def parse_params(self, value):
		value = str(value)
		reps = re.compile('\'(\$\{.*?\})\'')
		keys = reps.findall(value)
		for key in keys:
			value = value.replace(key, reponses[key[2:-1]])
		value = eval(value)
		return value

	def Session(self,method,url,user_id=None,params=None,json=None,url_id=None):
		if user_id==None:
			user_id=Session()
		if url_id==None:
			url=self.urls[0]+url
		else:
			url=self.urls[url_id]+url
		if params==None and json==None:
			req=Request(method,url)
		elif params==None:
			req=Request(method,url,json=json)
		elif json==None:
			req=Request(method,url,params=params)
		else:
			req=Request(method,url,params=params,json=json)
		prepped = user_id.prepare_request(req)
		return user_id.send(prepped)
	def tearDown(self):
		pass


#encoding: utf-8
from setuptools import find_packages, setup
setup(

        name='minterface',
        version='0.0.3',
        description='minterface',
        license='MIT',
        author='KingMckay',
        author_email='kingmckay58@gmail.mmdminterface',
        url='https://github.com/mckay58/minterface',
        packages=find_packages(),
        install_requires=["PyMySQL", "xlrd", "sshtunnel", "requests", "PyYAML"],
        classifiers=[
            # How mature is this project? Common values are
            #   3 - Alpha
            #   4 - Beta
            #   5 - Production/Stable
            'Development Status :: 3 - Alpha',

            # Indicate who your project is intended for
            'Intended Audience :: Developers',
            'Topic :: Software Development :: Build Tools',

            # Pick your license as you wish (should match "license" above)
             'License :: OSI Approved :: MIT License',

            # Specify the Python versions you support here. In particular, ensure
            # that you indicate whether you support Python 2, Python 3 or both.
            'Programming Language :: Python :: 3.5',
            'Programming Language :: Python :: 3.6',
        ],

)
